# Core Developers
----------
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi)) **
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri)) **

** **Maintainer**

# Other Contributors
----------
- [@boreshnavard](https://github.com/boreshnavard) ++

++ Graphic designer
